# README

## Introduction

## Install

pip install water-pipe

## Sample code

```python
from water_pipe import channel

```

## Dependency

```shell
pip install impyla
pip install psycopg2
pip install mysqlclinet
pip install openpyxl
```
